Topic - 话题
============

..  topic:: 注意

    请先查看 :doc:`说明 <intro>` 了解一下知乎相关类的文档的阅读方法。
    否则你会看不懂下面的东西的…………

..  automodule:: zhihu_oauth.zhcls.topic
    :members:
    :undoc-members:

话题索引的获取完整例子和输出参见 `Issue #67
<https://github.com/7sDream/zhihu-oauth/issues/67#issuecomment-296392977>`_ 。
